@@ -1587,7 +1587,7 @@ flip_vert ()
 
 void
 copy_obj ()
-/** creates a copy of the marked object almost on top of it, transfering the 
+/** creates a copy of the marked object, transfering the 
 mark to the newly generated fragment. Dangling bonds, where one end is 
 linked to something outside the box, are ignored. **/
 {
@@ -1608,15 +1608,15 @@ linked to something outside the box, are ignored. **/
   for (d = 0; d < n_end; d++)
     {
       if (hp_bond->smarked && hp_bond->tmarked)
-	add_struct (hp_bond->x + 5, hp_bond->y + 5,
-		    hp_bond->tx + 5, hp_bond->ty + 5, hp_bond->bond, 1, 1,hp_bond->decoration, hp_bond->color);
+	add_struct (hp_bond->x , hp_bond->y ,
+		    hp_bond->tx , hp_bond->ty , hp_bond->bond, 1, 1,hp_bond->decoration, hp_bond->color);
       hp_bond->smarked = hp_bond->tmarked = 0;
       hp_bond = hp_bond->next;
     }
   for (d = 0; d < nc_end; d++)
     {
       if (hp_atom->marked)
-	add_char (hp_atom->x + 5, hp_atom->y + 5, hp_atom->c,
+	add_char (hp_atom->x , hp_atom->y , hp_atom->c,
 		  hp_atom->direct, 1, hp_atom->color,hp_atom->font,hp_atom->size);
       hp_atom->marked = 0;
       hp_atom = hp_atom->next;
@@ -1627,10 +1627,10 @@ linked to something outside the box, are ignored. **/
     {
       if (hp_spline->marked)
 	{
-	  add_spline (hp_spline->x0 + 5, hp_spline->y0 + 5,
-		      hp_spline->x1 + 5, hp_spline->y1 + 5,
-		      hp_spline->x2 + 5, hp_spline->y2 + 5,
-		      hp_spline->x3 + 5, hp_spline->y3 + 5,
+	  add_spline (hp_spline->x0 , hp_spline->y0 ,
+		      hp_spline->x1 , hp_spline->y1 ,
+		      hp_spline->x2 , hp_spline->y2 ,
+		      hp_spline->x3 , hp_spline->y3 ,
 		      hp_spline->type, 1, hp_spline->color);
 	  hp_spline->marked = 0;
 	}
@@ -2082,7 +2082,7 @@ has_label(int x, int y)
   for (d = 0; d < hp->nc; d++)
     {
       if ( abs(hp_atom->x-x)<5  && abs(hp_atom->y-y)<5 )
- 	return hp_atom->size;
+ 	return d;
       hp_atom = hp_atom->next;
     }
   return -1;
