@@ -280,7 +280,7 @@ char **outtype;
 char **outmode;
 int babelout;
 extern char *babel;
-extern GdkGC *mygc[7],*background_gc;
+extern GdkGC *mygc[8],*background_gc,*hlgc;
 extern int curpen;
 extern int gridtype;
 extern int gridx,gridy;
