@@ -159,17 +159,64 @@ Display_Mol ()
 #if 1
 //constant clipping factor works better than original 4*size_factor
 	if ( !use_whiteout) {
+	        int siz,strl;
+	        int j;
 		i=has_label(hpc->x,hpc->y);
 		if (i>=0) {
+                 hpc_c = dac_root.next;
+                 for (j = 0; j < i; j++)hpc_c=hpc_c->next;
+		 siz=hpc_c->size;  // font size
+                 if (y-ty==0&& hpc_c->direct ==0) { // horizontal bond, left justified label
+                      strl=0;
+                      for (i=0;i<strlen(hpc_c->c);i++) { // count regular characters in label
+                        if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
+                        && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
+                        strl++;
+                      }
+                   if (tx>x) {
+                      x+=(strl-1)*3.2*(siz+1); // move bond endpoint off label
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='H') x+=5;
+                      if (hpc_c->c[strlen(hpc_c->c)-2]=='_')
+                        x-=1.6*(siz+1);        // adjust for trailing subscripts
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='}')
+                        x-=4.8*(siz+1);
+                   }     
+                   else {
+                      }
+		 }
 		int ox=x;
-				x += (3.2*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
-				y += (3.2*(i+1)/calc_vector(abs(tx-ox),abs(ty-y))) *(ty-y);
+				x += (3.2*(siz+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				y += (3.2*(siz+1)/calc_vector(abs(tx-ox),abs(ty-y))) *(ty-y);
 				}
 		i=has_label(hpc->tx,hpc->ty);
 		if (i>=0) {
+                 hpc_c = dac_root.next;
+                 for (j = 0; j < i; j++)hpc_c=hpc_c->next;
+		 siz=hpc_c->size;
+                 if (y-ty==0 ){
+                      strl=0;
+                      for (i=0;i<strlen(hpc_c->c);i++) {
+                        if(hpc_c->c[i] != '_' && hpc_c->c[i] != '^' 
+                        && hpc_c->c[i] != '{' && hpc_c->c[i] != '{')
+                        strl++;
+                      }
+                   if ( hpc_c->direct<-1) {
+                      if (tx>x)
+                        tx-=(strlen(hpc_c->c)-1)*3.2*(siz+1);
+//QUAK                      else
+//QUAK                       tx+=(strlen(hpc_c->c)-1)*3.2*(siz+1);
+                   }
+                   else if ( hpc_c->direct==0 && tx<x) {
+                        tx+=(strl-1)*3.2*(siz+1);
+                      if (hpc_c->c[strlen(hpc_c->c)-2]=='_')
+                        tx-=1.6*(siz+1);
+                      if (hpc_c->c[strlen(hpc_c->c)-1]=='}')
+                        tx-=4.8*(siz+1);
+                    }    
+                }  
 		int otx=tx;
-				tx -= (3.2*(i+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
-				ty -= (3.2*(i+1)/calc_vector(abs(otx-x),abs(ty-y))) *(ty-y);
+				tx -= (3.2*(siz+1)/calc_vector(abs(tx-x),abs(ty-y))) *(tx-x);
+				ty -= (3.2*(siz+1)/calc_vector(abs(otx-x),abs(ty-y))) *(ty-y);
 				}
 		}		
 #endif
@@ -460,7 +507,7 @@ Drawline (int x, int y, int tx, int ty, int active, int color)
 		   (gint) (x * size_factor), (gint) (y * size_factor),
 		   (gint) (tx * size_factor), (gint) (ty * size_factor));
   else if (active)
-    gdk_draw_line (picture, drawing_area->style->bg_gc[GTK_STATE_SELECTED],
+    gdk_draw_line (picture, hlgc,
 		   (gint) (x * size_factor), (gint) (y * size_factor),
 		   (gint) (tx * size_factor), (gint) (ty * size_factor));
   else
@@ -497,7 +544,7 @@ DrawAcross (int x, int y, int tx, int ty, int active,int color)
   if (xbmflag)
   thegc=drawing_area->style->black_gc;
   else if (active)
-  thegc=drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+  thegc=hlgc;
   else 
   thegc=mygc[color];
     gdk_draw_line (picture, thegc,
@@ -527,7 +574,7 @@ DrawDashed (int x, int y, int tx, int ty, int active,int color)
   if (xbmflag)
   thegc= drawing_area->style->black_gc;
   else if (active)
-  thegc=drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+  thegc=hlgc;
   else
   thegc=mygc[color];
   
@@ -563,7 +610,7 @@ if (npoints>99)npoints=99;
   if (xbmflag)
   thegc= drawing_area->style->black_gc;
   else if (active)
-  thegc=drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+  thegc=hlgc;
   else
   thegc=mygc[color];
 
@@ -583,7 +630,7 @@ DrawWide (int x, int y, int tx, int ty, int active,int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
   thegc=mygc[color];
   coord = center_double_bond (x, y, tx, ty, 6); 
@@ -613,7 +660,7 @@ DrawStripe (int x, int y, int tx, int ty, int active, int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
   thegc=mygc[color];
   coord = center_double_bond (x, y, tx, ty, 4); 
@@ -649,7 +696,7 @@ DrawCircle (int x, int y, int tx, int ty, int active,int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active )
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
     thegc=mygc[color];
   radius = calc_vector (abs (tx - x), abs (ty - y)) * size_factor;
@@ -660,7 +707,7 @@ DrawCircle (int x, int y, int tx, int ty, int active,int color)
 		2 * radius, 0, 360 * 64);
   if (drawmode == 3 && !xbmflag)
     {
-      thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+      thegc = hlgc;
       gdk_draw_rectangle (picture, thegc, TRUE, x * size_factor - 1,
 			  y * size_factor - 1, 3, 3);
       gdk_draw_rectangle (picture, thegc, TRUE, tx * size_factor - 1,
@@ -683,7 +730,7 @@ DrawWiggly (int x, int y, int tx, int ty, int active, int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-  thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+  thegc = hlgc;
   else
   thegc=mygc[color];
 
@@ -731,7 +778,7 @@ DrawArrow (int x, int y, int tx, int ty, int head, int active, int color)
   if (xbmflag)
     thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
     thegc= mygc[color];
     
@@ -796,7 +843,7 @@ DrawDashedWedge (int x, int y, int tx, int ty, int active,int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else 
   thegc= mygc[color];
   
@@ -835,7 +882,7 @@ DrawWedge (int x, int y, int tx, int ty, int active, int color)
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc; 
   else
     thegc = mygc[color];
   xlen = tx - x;
@@ -916,7 +963,7 @@ Drawspline (int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3,
   if (xbmflag)
     thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
     thegc = mygc[color];
     
@@ -1080,7 +1127,7 @@ Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int se
   if (xbmflag)
   thegc = drawing_area->style->black_gc;
   else if (active)
-    thegc = drawing_area->style->bg_gc[GTK_STATE_SELECTED];
+    thegc = hlgc;
   else
     thegc = mygc[thecolor];
     
